//importing the required methods
import {
  select,
  csv,
  scaleLinear,
  scaleTime,
  extent,
  axisLeft,
  axisBottom,
  line,
  curveBasis
} from 'd3';

//selecting the svg and storing it in a variable
const svg = select('svg');

//Adding the attributes width and height to the svg
const width = +svg.attr('width');
const height = +svg.attr('height');

//Rendering the data
const render = data => {
  const title = 'CO2 Emission over the Years';
  
  const xValue = d => d.Total;
  const xAxisLabel = 'Total';
  
  const yValue = d => d.Year;
  const circleRadius = 6;
  const yAxisLabel = 'Year';
  
  // set the dimensions and margins of the graph
  const margin = { top: 60, right: 40, bottom: 88, left: 130 };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  // setting the x-axis range
  const xScale = scaleLinear()
    .domain(extent(data, xValue))
    .range([0, innerWidth])
    .nice();
  
  //setting the y-axis range
  const yScale = scaleLinear()
    .domain(extent(data, yValue))
    .range([innerHeight, 0])
    .nice();
  
  //append a group element to the svg
  const g = svg.append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`);
  
  //defining the x-axis
  const xAxis = axisBottom(xScale)
    .tickSize(-innerHeight)
    .tickPadding(15);
  
  //defining the y-axis
  const yAxis = axisLeft(yScale)
    .tickSize(-innerWidth)
    .tickPadding(10);
  
  //appending the y-axis group to the line chart group
  const yAxisG = g.append('g').call(yAxis);
  yAxisG.selectAll('.domain').remove();
  
  //appending the label for the y-axis
  yAxisG.append('text')
      .attr('class', 'axis-label')
      .attr("y", 0 - margin.left+35)
      .attr("x",0 - (height / 3))
      .attr('dy', '.2em')
      .attr('fill', 'black')
      .attr('transform', `rotate(-90)`)
      .attr('text-anchor', 'middle')
      .text(yAxisLabel);

  //appending the x-axis group to the line chart group
  const xAxisG = g.append('g').call(xAxis)
    .attr('transform', `translate(0,${innerHeight})`);
  
  xAxisG.select('.domain').remove();
  
  //appending the label for the x-axis
  xAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', 80)
      .attr('x', innerWidth / 2)
      .attr('fill', 'black')
      .text(xAxisLabel);
  
  //defining the function to generate the line
  const lineGenerator = line()
    .x(d => xScale(xValue(d)))
    .y(d => yScale(yValue(d)))
    .curve(curveBasis);
  
   // Adding the valueline path
  g.append('path')
      .attr('class', 'line-path')
      .attr('d', lineGenerator(data));
  
  //text title for the Line chart
  g.append('text')
      .attr('class', 'title')
      .attr('y', -7)
      .text(title);
};

//get the data
csv('https://gist.githubusercontent.com/gallachaitanya/a05b82dcbb9a5f1dcfa8d6a2a4960c25/raw/7179a02c446fa1178ed6121ead85040b374fa091/CO2%2520emission.csv')
  .then(data => {
  //format the data
    data.forEach(d => {
      d.Year = +d.Year;
      d.Total = +d.Total;
    });
    render(data);
  });